

# Generated by the protocol buffer compiler.  DO NOT EDIT!
# sources: blickfeld/eye_safety/data/pulse_mode.proto
# plugin: python-betterproto
from dataclasses import dataclass

import blickfeld_qb2.betterproto as betterproto
import blickfeld_qb2.betterproto.lib.google.protobuf as betterproto_lib_google_protobuf


class PulseMode(betterproto.Enum):
    """
    The pulse mode specifies the system's laser energy that is emitted with
    each laser pulse. The different modes provide options to cater to different
    applications.
    """

    PULSE_MODE_UNSPECIFIED = 0
    """Unspecified pulse mode"""

    PULSE_MODE_A = 1
    """
    Default pulse mode providing a high pulse rate for a dense point cloud with
    sufficient detection rate for most use cases
    """

    PULSE_MODE_B = 2
    """
    Pulse mode with medium single pulse laser energy, balancing between A and C
    """

    PULSE_MODE_C = 3
    """
    Pulse mode with high single pulse laser energy, improving detection for far
    range or low reflectivity at the cost of pulse rate
    """
