

# Generated by the protocol buffer compiler.  DO NOT EDIT!
# sources: blickfeld/config/data/watch_event.proto
# plugin: python-betterproto
from dataclasses import dataclass

import blickfeld_qb2.betterproto as betterproto
import blickfeld_qb2.betterproto.lib.google.protobuf as betterproto_lib_google_protobuf


class WatchEventType(betterproto.Enum):
    """Type of watch event"""

    TYPE_UNSPECIFIED = 0
    """Unspecified type"""

    TYPE_CREATED = 1
    """A value for a key or map entry has been stored the first time"""

    TYPE_UPDATED = 2
    """A value for a key or map entry has been updated"""

    TYPE_DELETED = 3
    """A value for a key or map entry has been deleted"""


@dataclass(eq=False, repr=False)
class WatchEvent(betterproto.Message):
    """Watch event which is emitted on a config change"""

    pass
