

# Generated by the protocol buffer compiler.  DO NOT EDIT!
# sources: blickfeld/beam_deflection_control/config/module.proto
# plugin: python-betterproto
from dataclasses import dataclass

import blickfeld_qb2.betterproto as betterproto
import blickfeld_qb2.betterproto.lib.google.protobuf as betterproto_lib_google_protobuf


class Module(betterproto.Enum):
    """
    This enum defines the different modules that can run the beam deflection
    control firmware and thus can be communicated with. It needs to be passed
    as metadata when opening the gRPC channel in order to select the module.
    """

    MODULE_UNSPECIFIED = 0
    """Unused zero value"""

    MODULE_VERTICAL = 1
    """Vertical beam deflection unit"""

    MODULE_HORIZONTAL = 2
    """Horizontal beam deflection unit"""
